/*
Copyright (c) 2001                      RIPE NCC


All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the author not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

/*
-------------------------------------------------------------------------------
Module Header
Filename          : summarize.C
Author            : Rene Wilhelm
Date              : 14-NOV-2001
Description       : Main program for creating TTM delay summary pages
Language Version  : C++
OSs Tested        : Solaris 2.6, Solaris 8, Debian Linux 2.2

Command line      :
    required args : -p <timeperiod>  iso8601 format time period; sets time
				     period and last day for summaries
    optional args : -o <outputdir>   directory tree where to store HTML pages
		    -w		     Create summary pages from week files
		    -v		     verbose

$Id: summarize.C,v 1.3 2003/05/16 13:57:42 ttraffic Exp $
-------------------------------------------------------------------------------
*/

#define NUMINTERVALS 4	 // difficult to autodetect from data

#include <TROOT.h>
#include <TApplication.h>
#include <stdlib.h>
#include <time.h>
#include "utils.h"
#include "TestBoxConfig.h"
#include "TTMOptions.h"
#include "TTMSummaryChain.h"

static char const rcsid[] = "$Id: summarize.C,v 1.3 2003/05/16 13:57:42 ttraffic Exp $";
static char const *rcsid_p = rcsid;   // Prevent g++ from optimizing out rcsid

int main (int argc, char** argv) {


// fetch options and set defaults

        TTMOptions options(argc, argv, "6vwo:p:");

// Initialize ROOT system

	TROOT simple ("TTM", "Summaries");
	gROOT->SetBatch();                   // no graphics windows

	TApplication* app = new TApplication("delayStats", NULL, NULL, NULL, 0);

// now we can start ...

        
        TestBoxConfig config(options);

	TTMSummaryChain summary;
	summary.SetConfig(options, config, NUMINTERVALS);

	summary.Chain();
	summary.OutputHTML(0.4);
	summary.OutputXML();

	return(0);
}
